@@ -1,7 +1,9 @@
 import urllib2
 import time
 import os
-import requests
+#import requests
+import json
+from requests_futures.sessions import FuturesSession
 from dofler.common import md5hash, log
 
 class DoflerClient(object):
@@ -15,7 +17,7 @@ class DoflerClient(object):
         self.ssl = ssl
         self.anonymize = anon
         self.username = username
-        self.opener = requests.Session()
+        self.opener = FuturesSession(max_workers=10)
         self.login(username, password)
 
 
@@ -53,10 +55,10 @@ class DoflerClient(object):
 
         :return: None
         '''
-        self.call('/auth/login', {
+        self.call('/post/login', {
             'username': username,
             'password': password
-        })
+        }).result()
 
 
     def account(self, username, password, info, proto, parser):
@@ -145,4 +147,34 @@ class DoflerClient(object):
         :type env: str 
         :return: None 
         '''
-        self.call('/post/reset', {'type': env})
\ No newline at end of file
+        self.call('/post/reset', {'type': env})
+
+
+    def services(self):
+        '''
+        Gets the current service statuses. 
+        '''
+        return json.loads(self.call('/post/services', {
+                'action': 'none',
+                'parser': 'none',
+        }).result().content)
+
+
+    def start(self, name):
+        '''
+        Starts the defined service. 
+        '''
+        return json.loads(self.call('/post/services', {
+                'action': 'Start', 
+                'parser': name
+        }).result().content)
+
+
+    def stop(self, name):
+        '''
+        Stops the defined service. 
+        '''
+        return json.loads(self.call('/post/services', {
+            'action': 'Stop', 
+            'parser': name
+        }).result().content)
